test = "A inceput razboiul, sa-l ia dreaq pe Putin"


def find_index(colectie, element):
    for index, value in enumerate(colectie):
        if value == element:
            return index

print("print din modulul a")